import * as React from 'react';
import { View, Dimensions, ScrollView } from 'react-native';
export function MirrorLists({
  data,
  horizontalRenderItem,
  verticalRenderItem,
  keyExtractor,
  reverse = false
}) {
  const horizontalListRef = React.useRef(null);
  const verticalListRef = React.useRef(null);
  const [horizontalItemWidth, setHorizontalItemWidth] = React.useState(0);
  const [horizontalItemHeight, setHorizontalItemHeight] = React.useState(0);
  const [verticalListHeight, setVerticalListHeight] = React.useState(0);
  const [horizontalScrollActive, setHorizontalScrollActive] = React.useState(false);
  const [verticalScrollActive, setVerticalScrollActive] = React.useState(false);

  function onScrollHorizontal({
    nativeEvent
  }) {
    var _verticalListRef$curr;

    if (verticalScrollActive) return;
    const offset = nativeEvent.contentOffset.x / horizontalItemWidth * verticalListHeight;
    verticalListRef === null || verticalListRef === void 0 ? void 0 : (_verticalListRef$curr = verticalListRef.current) === null || _verticalListRef$curr === void 0 ? void 0 : _verticalListRef$curr.scrollTo({
      animated: false,
      y: offset
    });
  }

  function onScrollVertical({
    nativeEvent
  }) {
    var _horizontalListRef$cu;

    if (horizontalScrollActive) return;
    const offset = nativeEvent.contentOffset.y / verticalListHeight * horizontalItemWidth;
    horizontalListRef === null || horizontalListRef === void 0 ? void 0 : (_horizontalListRef$cu = horizontalListRef.current) === null || _horizontalListRef$cu === void 0 ? void 0 : _horizontalListRef$cu.scrollTo({
      animated: false,
      x: offset
    });
  }

  function onHorizontalItemLayout({
    nativeEvent
  }) {
    if (!horizontalItemWidth && !horizontalItemHeight) {
      setHorizontalItemWidth(nativeEvent.layout.width);
      setHorizontalItemHeight(nativeEvent.layout.height);
    }
  }

  return /*#__PURE__*/React.createElement(View, {
    style: [{
      flex: 1,
      flexDirection: reverse ? 'column-reverse' : 'column'
    }]
  }, /*#__PURE__*/React.createElement(ScrollView, {
    ref: horizontalListRef,
    style: {
      flexGrow: 0
    },
    horizontal: true,
    showsHorizontalScrollIndicator: false,
    onScroll: onScrollHorizontal,
    onScrollBeginDrag: () => setHorizontalScrollActive(true),
    onMomentumScrollEnd: () => setHorizontalScrollActive(false),
    scrollEventThrottle: 1,
    decelerationRate: 'fast',
    snapToInterval: horizontalItemWidth
  }, /*#__PURE__*/React.createElement(View, {
    style: {
      width: Dimensions.get('window').width * 0.5 - horizontalItemWidth / 2
    }
  }), data.map(item => {
    return /*#__PURE__*/React.createElement(View, {
      key: keyExtractor({
        item
      }),
      onLayout: onHorizontalItemLayout
    }, horizontalRenderItem({
      item
    }));
  }), /*#__PURE__*/React.createElement(View, {
    style: {
      width: Dimensions.get('window').width * 0.5 - horizontalItemWidth / 2
    }
  })), /*#__PURE__*/React.createElement(ScrollView, {
    ref: verticalListRef,
    style: {
      flex: 1
    },
    onLayout: ({
      nativeEvent
    }) => setVerticalListHeight(nativeEvent.layout.height),
    onScroll: onScrollVertical,
    onScrollBeginDrag: () => setVerticalScrollActive(true),
    onMomentumScrollEnd: () => setVerticalScrollActive(false),
    scrollEventThrottle: 1,
    snapToInterval: verticalListHeight,
    decelerationRate: 'fast'
  }, data.map(item => {
    return /*#__PURE__*/React.createElement(View, {
      key: keyExtractor({
        item
      }),
      style: {
        height: verticalListHeight
      }
    }, verticalRenderItem({
      item
    }));
  })));
}
//# sourceMappingURL=index.js.map